@@ -78,7 +78,8 @@
 // a frame contains a pointer to the page object, its geometry and the
 // transition effect to the next frame
 struct PresentationFrame {
-    PresentationFrame() = default;
+    explicit PresentationFrame(const Okular::Page *_page)
+        : page(_page) {};
 
     ~PresentationFrame()
     {
@@ -180,7 +181,7 @@ PresentationWidget::PresentationWidget(QWidget *parent, Okular::Document *doc, D
     m_topBar->setObjectName(QStringLiteral("presentationBar"));
     m_topBar->setMovable(false);
     m_topBar->layout()->setContentsMargins(0, 0, 0, 0);
-    m_topBar->addAction(QIcon::fromTheme(layoutDirection() == Qt::RightToLeft ? QStringLiteral("go-next") : QStringLiteral("go-previous")), i18n("Previous Page"), this, SLOT(slotPrevPage()));
+    m_topBar->addAction(QIcon::fromTheme(layoutDirection() == Qt::RightToLeft ? QStringLiteral("go-next") : QStringLiteral("go-previous")), i18n("Previous Page"), this, &PresentationWidget::slotPrevPage);
     m_pagesEdit = new KLineEdit(m_topBar);
     QSizePolicy sp = m_pagesEdit->sizePolicy();
     sp.setHorizontalPolicy(QSizePolicy::Minimum);
@@ -197,7 +198,7 @@ PresentationWidget::PresentationWidget(QWidget *parent, Okular::Document *doc, D
     pagesLabel->setText(QLatin1String(" / ") + QString::number(m_document->pages()) + QLatin1String(" "));
     m_topBar->addWidget(pagesLabel);
     connect(m_pagesEdit, &QLineEdit::returnPressed, this, &PresentationWidget::slotPageChanged);
-    m_topBar->addAction(QIcon::fromTheme(layoutDirection() == Qt::RightToLeft ? QStringLiteral("go-previous") : QStringLiteral("go-next")), i18n("Next Page"), this, SLOT(slotNextPage()));
+    m_topBar->addAction(QIcon::fromTheme(layoutDirection() == Qt::RightToLeft ? QStringLiteral("go-previous") : QStringLiteral("go-next")), i18n("Next Page"), this, &PresentationWidget::slotNextPage);
     m_topBar->addSeparator();
     QAction *playPauseAct = collection->action(QStringLiteral("presentation_play_pause"));
     playPauseAct->setEnabled(true);
@@ -236,7 +237,7 @@ PresentationWidget::PresentationWidget(QWidget *parent, Okular::Document *doc, D
     QWidget *spacer = new QWidget(m_topBar);
     spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::MinimumExpanding);
     m_topBar->addWidget(spacer);
-    m_topBar->addAction(QIcon::fromTheme(QStringLiteral("application-exit")), i18n("Exit Presentation Mode"), this, SLOT(close()));
+    m_topBar->addAction(QIcon::fromTheme(QStringLiteral("application-exit")), i18n("Exit Presentation Mode"), this, &PresentationWidget::close);
     m_topBar->setAutoFillBackground(true);
     showTopBar(false);
     // change topbar background color
@@ -335,8 +336,7 @@ void PresentationWidget::notifySetup(const QVector<Okular::Page *> &pageSet, int
     // create the new frames
     float screenRatio = (float)m_height / (float)m_width;
     for (const Okular::Page *page : pageSet) {
-        PresentationFrame *frame = new PresentationFrame();
-        frame->page = page;
+        PresentationFrame *frame = new PresentationFrame(page);
         const QList<Okular::Annotation *> annotations = page->annotations();
         for (Okular::Annotation *a : annotations) {
             if (a->subType() == Okular::Annotation::AMovie) {
@@ -1302,7 +1302,9 @@ void PresentationWidget::generateOverlay()
     color = pal.color(QPalette::Active, QPalette::Highlight);
     int sRed = color.red(), sGreen = color.green(), sBlue = color.blue();
     // pointers
-    unsigned int *data = reinterpret_cast<unsigned int *>(image.bits()), *shadowData = reinterpret_cast<unsigned int *>(shadow.bits()), pixels = image.width() * image.height();
+    unsigned int *data = reinterpret_cast<unsigned int *>(image.bits());
+    const unsigned int *shadowData = reinterpret_cast<unsigned int *>(shadow.bits());
+    unsigned int pixels = image.width() * image.height();
     // cache data (reduce computation time to 26%!)
     int c1 = -1, c2 = -1, cR = 0, cG = 0, cB = 0, cA = 0;
     // foreach pixel
@@ -1649,7 +1651,7 @@ void PresentationWidget::slotChangeDrawingToolEngine(const QDomElement &element)
 
 void PresentationWidget::slotAddDrawingToolActions()
 {
-    DrawingToolActions *drawingToolActions = qobject_cast<DrawingToolActions *>(sender());
+    const DrawingToolActions *drawingToolActions = qobject_cast<DrawingToolActions *>(sender());
 
     const QList<QAction *> actionsList = drawingToolActions->actions();
     for (QAction *action : actionsList) {
@@ -2262,7 +2264,7 @@ void PresentationWidget::slotProcessMovieAction(const Okular::MovieAction *actio
         return;
     }
 
-    Okular::Movie *movie = movieAnnotation->movie();
+    const Okular::Movie *movie = movieAnnotation->movie();
     if (!movie) {
         return;
     }
